#!jinja2

# A somewhat complex suite put together for the IS-ENES2 Workshop in Lisbon
# 2016.

{% if not batch_system is defined %}
    {% set batch_system = 'background' %}
{% endif %}
{% if not sleep_time is defined %}
    {% set sleep_time = 1 %}
{% endif %}
[meta]
    title = "Complex Suite Demo"
    description = "This is a super-elaborate obfuscated version of a suite with no Jinja2 to condense it down."
[cylc]
    UTC mode = True
    [[events]]
        timeout handler = rose suite-hook --mail --shutdown
        timeout = P1D                       # 1 day.
[scheduling]
    initial cycle point = 20150219T00
    final cycle point = 20150220T00
    runahead limit = PT6H
    [[special tasks]]
        clock-trigger = \
                          long_start_00(PT2H40M), brief_start_00(PT6H15M), \
                          long_start_06(PT2H40M), brief_start_06(PT6H15M), \
                          long_start_12(PT2H40M), brief_start_12(PT6H15M), \
                          long_start_18(PT2H40M), brief_start_18(PT6H15M), \
                          long_res_create(-PT1H20M), brief_res_create(PT1H30M), \
                          ensemble_start_00(PT3H30M), ensemble_start_06(PT3H30M), \
                          ensemble_start_12(PT3H30M), ensemble_start_18(PT3H30M), \
                          ensemble_res_create(-PT30M), ensembles_res_create(-PT30M)
    [[dependencies]]
        [[[R1]]]
            graph = """
                     install_cold
                     install_cold_mirror
                     install_cold & longbrief_install_startdata_cold => long_start & brief_start
                     install_cold & ensemble_install_startdata_cold => ensemble_start
            """
        [[[ T00 ]]]
            graph = """
                housekeep => archive_logs
            """
[runtime]
    [[root]]
    {% if cylc_compat_mode is defined and cylc_compat_mode == '6' %}
        command scripting = sleep {{ sleep_time }}
        [[[job submission]]]
            method = {{ batch_system }}
    {% else %}
        script = sleep {{ sleep_time }}
        [[[job]]]
            batch system = {{ batch_system }}
    {% endif %}
    [[HPC]]
    [[HPC_BACKUP]]
    [[CORETYPE_PARALLEL]]
    [[CORETYPE_SHARED]]
    [[ARCHIVE]]
        inherit = CORETYPE_SHARED
    [[INSTALL_COLD]]
        inherit = CORETYPE_SHARED
    [[INSTALL_DIAG]]
    [[LOCAL]]
    [[OS_RES_CREATE]]
        inherit = None, HPC, CORETYPE_SHARED
    [[OS_RES_DELETE]]
        inherit = None, HPC, CORETYPE_SHARED
    [[OS_START]]
        inherit = None, LOCAL
    [[RETRY_TASK]]
    [[archive_logs]]
        inherit = None, LOCAL, ARCHIVE
    [[housekeep]]
        inherit = None, LOCAL
    [[install_cold]]
        inherit = INSTALL_COLD, HPC
    [[install_cold_mirror]]
        inherit = INSTALL_COLD, HPC_BACKUP
[scheduling]
    [[dependencies]]
        [[[ T00 ]]]
            graph = """
                long_res_create   => long_start_00   => long_start
                brief_res_create   => brief_start_00   => brief_start
                brief_forecast_end => brief_hpc_backup_daily => housekeep
                long_dispersion_proc_completed => long_dispersion_archive_prep => long_dispersion_archive
            """
        [[[ T06 ]]]
            graph = """
                brief_forecast[-PT6H]                             => brief_wagtail_look_at_snow & brief_wagtail_look_at_wagtail_ice   \
                                                               => brief_forecast_redo_daily                              \
                                                               => brief_forecast
                brief_start                                      => brief_wagtail_look_at_snow & brief_wagtail_look_at_wagtail_ice
                brief_start                                      => brief_observations_wagtail_background => brief_observations_wagtail_look_at
                brief_start                                      => brief_observations_process_wagtail_background => brief_observations_process_wagtail_look_at \
                                                               => brief_observations_db_stuff_wagtail => brief_archive
                long_res_create   => long_start_06   => long_start
                brief_res_create   => brief_start_06   => brief_start
            """
        [[[ T12 ]]]
            graph = """
                long_res_create   => long_start_12   => long_start
                brief_res_create   => brief_start_12   => brief_start
            """
        [[[ T18 ]]]
            graph = """
                long_res_create   => long_start_18   => long_start
                brief_res_create   => brief_start_18   => brief_start
            """
        [[[ T00, T12 ]]]
            graph = """
                long_assimilation_look_at_larger                      =>  long_forecast_long
                long_forecast_long => LONG_OBS_PROCESS_LOOK_AT:succeed-all => long_observations_db_stuff_wagtail => long_archive_long => housekeep
                long_forecast_long                       => long_verificationmodel_database
                long_forecast_subjob_tZT                     => long_verificationmodel_database => long_verificationmodel_database_induced
                long_verificationmodel_database_induced & brief_verificationmodel_database_induced => housekeep
                long_forecast_long:start                                         \
                                                 => long_forecast_tA       \
                                                 => long_forecast_tB       \
                                                 => long_forecast_tC       \
                                                 => long_forecast_tD       \
                                                 => long_forecast_tE       \
                                                 => long_forecast_tF       \
                                                 => long_forecast_tG       \
                                                 => long_forecast_tH       \
                                                 => long_forecast_tI       \
                                                 => long_forecast_tB0       \
                                                 => long_forecast_tB3       \
                                                 => long_forecast_tB6       \
                                                 => long_forecast_tB9       \
                                                 => long_forecast_tBA       \
                                                 => long_forecast_tBB       \
                                                 => long_forecast_tJ       \
                                                 => long_forecast_tBC       \
                                                 => long_forecast_tBD       \
                                                 => long_forecast_tBE       \
                                                 => long_forecast_tC0       \
                                                 => long_forecast_tC3       \
                                                 => long_forecast_tC6       \
                                                 => long_forecast_tK       \
                                                 => long_forecast_tKA       \
                                                 => long_forecast_tKB       \
                                                 => long_forecast_tKC       \
                                                 => long_forecast_tKD       \
                                                 => long_forecast_tKE       \
                                                 => long_forecast_tKF       \
                                                 => long_forecast_tZA       \
                                                 => long_forecast_tZB       \
                                                 => long_forecast_tZC       \
                                                 => long_forecast_tM       \
                                                 => long_forecast_tZD       \
                                                 => long_forecast_tZE       \
                                                 => long_forecast_tL       \
                                                 => long_forecast_tZF       \
                                                 => long_forecast_tZG       \
                                                 => long_forecast_tZH       \
                                                 => long_forecast_tN       \
                                                 => long_forecast_tZI       \
                                                 => long_forecast_tZJ       \
                                                 => long_forecast_tZK       \
                                                 => long_forecast_tZM       \
                                                 => long_forecast_tZN       \
                                                 => long_forecast_tZO       \
                                                 => long_forecast_tO       \
                                                 => long_forecast_tZP       \
                                                 => long_forecast_tZQ       \
                                                 => long_forecast_tZR       \
                                                 => long_forecast_tZS       \
                                                 => long_forecast_tZT       \
                                                 => housekeep
                long_forecast_long                 => long_forecast_end
                long_forecast_end & LONG_OBS_PROCESS_LOOK_AT:succeed-all         \
                                                 => long_res_delete
                long_forecast_tA             => long_forecast_subjob_tA     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tA           => long_local_preflight_checks
                long_forecast_subjob_tA           => long_thunderbirds_are_go
                long_forecast_tB             => long_forecast_subjob_tB     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tB           => long_local_preflight_checks
                long_forecast_subjob_tB           => long_thunderbirds_are_go
                long_forecast_tC             => long_forecast_subjob_tC     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tC           => long_local_preflight_checks
                long_forecast_subjob_tC           => long_thunderbirds_are_go
                long_forecast_tD             => long_forecast_subjob_tD     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tD           => long_local_preflight_checks
                long_forecast_subjob_tD           => long_thunderbirds_are_go
                long_forecast_tE             => long_forecast_subjob_tE     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tE           => long_local_preflight_checks
                long_forecast_subjob_tE           => long_thunderbirds_are_go
                long_forecast_tF             => long_forecast_subjob_tF     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tF           => long_local_preflight_checks
                long_forecast_subjob_tF           => long_thunderbirds_are_go
                long_forecast_tG             => long_forecast_subjob_tG     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tG           => long_local_preflight_checks
                long_forecast_subjob_tG           => long_thunderbirds_are_go
                long_forecast_tH             => long_forecast_subjob_tH     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tH           => long_local_preflight_checks
                long_forecast_subjob_tH           => long_thunderbirds_are_go
                long_forecast_tI             => long_forecast_subjob_tI     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tI           => long_local_preflight_checks
                long_forecast_subjob_tI           => long_thunderbirds_are_go
                long_forecast_tB0             => long_forecast_subjob_tB0     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tB0           => long_local_preflight_checks
                long_forecast_subjob_tB0           => long_thunderbirds_are_go
                long_forecast_tB3             => long_forecast_subjob_tB3     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tB3           => long_local_preflight_checks
                long_forecast_subjob_tB3           => long_thunderbirds_are_go
                long_forecast_tB6             => long_forecast_subjob_tB6     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tB6           => long_local_preflight_checks
                long_forecast_subjob_tB6           => long_thunderbirds_are_go
                long_forecast_tB9             => long_forecast_subjob_tB9     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tB9           => long_local_preflight_checks
                long_forecast_subjob_tB9           => long_thunderbirds_are_go
                long_forecast_tBA             => long_forecast_subjob_tBA     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tBA           => long_local_preflight_checks
                long_forecast_subjob_tBA           => long_thunderbirds_are_go
                long_forecast_tBB             => long_forecast_subjob_tBB     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tBB           => long_local_preflight_checks
                long_forecast_subjob_tBB           => long_thunderbirds_are_go
                long_forecast_tJ             => long_forecast_subjob_tJ     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tJ           => long_local_preflight_checks
                long_forecast_subjob_tJ           => long_thunderbirds_are_go
                long_forecast_tBC             => long_forecast_subjob_tBC     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tBC           => long_thunderbirds_are_go
                long_forecast_tBD             => long_forecast_subjob_tBD     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tBD           => long_thunderbirds_are_go
                long_forecast_tBE             => long_forecast_subjob_tBE     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tBE           => long_thunderbirds_are_go
                long_forecast_tC0             => long_forecast_subjob_tC0     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tC0           => long_thunderbirds_are_go
                long_forecast_tC3             => long_forecast_subjob_tC3     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tC3           => long_thunderbirds_are_go
                long_forecast_tC6             => long_forecast_subjob_tC6     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tC6           => long_thunderbirds_are_go
                long_forecast_tK             => long_forecast_subjob_tK     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tK           => long_thunderbirds_are_go
                long_forecast_tKA             => long_forecast_subjob_tKA     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tKA           => long_thunderbirds_are_go
                long_forecast_tKB             => long_forecast_subjob_tKB     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tKB           => long_thunderbirds_are_go
                long_forecast_tKC             => long_forecast_subjob_tKC     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tKC           => long_thunderbirds_are_go
                long_forecast_tKD             => long_forecast_subjob_tKD     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tKD           => long_thunderbirds_are_go
                long_forecast_tKE             => long_forecast_subjob_tKE     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tKE           => long_thunderbirds_are_go
                long_forecast_tKF             => long_forecast_subjob_tKF     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tKF           => long_thunderbirds_are_go
                long_forecast_tL             => long_forecast_subjob_tL     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tL           => long_thunderbirds_are_go
                long_forecast_tZF             => long_forecast_subjob_tZF     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZF           => long_thunderbirds_are_go
                long_forecast_tZG             => long_forecast_subjob_tZG     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZG           => long_thunderbirds_are_go
                long_forecast_tZH             => long_forecast_subjob_tZH     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZH           => long_thunderbirds_are_go
                long_forecast_tZA             => long_forecast_subjob_tZA     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZA           => long_thunderbirds_are_go
                long_forecast_tZB             => long_forecast_subjob_tZB     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZB           => long_thunderbirds_are_go
                long_forecast_tZC             => long_forecast_subjob_tZC     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZC           => long_thunderbirds_are_go
                long_forecast_tM             => long_forecast_subjob_tM     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tM           => long_thunderbirds_are_go
                long_forecast_tZD             => long_forecast_subjob_tZD     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZD           => long_thunderbirds_are_go
                long_forecast_tZE             => long_forecast_subjob_tZE     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZE           => long_thunderbirds_are_go
                long_forecast_tL             => long_forecast_subjob_tL     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tL           => long_thunderbirds_are_go
                long_forecast_tZF             => long_forecast_subjob_tZF     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZF           => long_thunderbirds_are_go
                long_forecast_tZG             => long_forecast_subjob_tZG     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZG           => long_thunderbirds_are_go
                long_forecast_tZH             => long_forecast_subjob_tZH     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZH           => long_thunderbirds_are_go
                long_forecast_tN             => long_forecast_subjob_tN     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tN           => long_thunderbirds_are_go
                long_forecast_tZI             => long_forecast_subjob_tZI     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZI           => long_thunderbirds_are_go
                long_forecast_tZJ             => long_forecast_subjob_tZJ     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZJ           => long_thunderbirds_are_go
                long_forecast_tZK             => long_forecast_subjob_tZK     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZK           => long_thunderbirds_are_go
                long_forecast_tZM             => long_forecast_subjob_tZM     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZM           => long_thunderbirds_are_go
                long_forecast_tZN             => long_forecast_subjob_tZN     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZN           => long_thunderbirds_are_go
                long_forecast_tZO             => long_forecast_subjob_tZO     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZO           => long_thunderbirds_are_go
                long_forecast_tO             => long_forecast_subjob_tO     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tO           => long_thunderbirds_are_go
                long_forecast_tZP             => long_forecast_subjob_tZP     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZP           => long_thunderbirds_are_go
                long_forecast_tZQ             => long_forecast_subjob_tZQ     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZQ           => long_thunderbirds_are_go
                long_forecast_tZR             => long_forecast_subjob_tZR     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZR           => long_thunderbirds_are_go
                long_forecast_tZS             => long_forecast_subjob_tZS     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZS           => long_thunderbirds_are_go
                long_forecast_tZT             => long_forecast_subjob_tZT     \
                                                 => long_local & long_bigleftright    \
                                                  & long_sync_happy            \
                                                  & long_archive_long
                long_forecast_subjob_tZT           => long_thunderbirds_are_go
                long_forecast_tF             => long_dispersion_tF          \
                                                 => long_dispersion_clock
                long_forecast_tB6             => long_dispersion_tB6          \
                                                 => long_dispersion_clock
                long_forecast_tBD             => long_dispersion_tBD          \
                                                 => long_dispersion_clock
                long_forecast_tKA             => long_dispersion_tKA          \
                                                 => long_dispersion_clock
                long_forecast_tL             => long_dispersion_tL          \
                                                 => long_dispersion_clock
                long_forecast_tZC             => long_dispersion_tZC          \
                                                 => long_dispersion_clock
                long_forecast_tZG             => long_dispersion_tZG          \
                                                 => long_dispersion_clock
                long_forecast_tZM             => long_dispersion_tZM          \
                                                 => long_dispersion_clock
                long_dispersion_clock                     => housekeep
                long_forecast_tD             => long_dispersion_proc_tD \
                                                 => long_dispersion_proc_completed
                long_forecast_tH             => long_dispersion_proc_tH \
                                                 => long_dispersion_proc_completed
                long_forecast_tB6             => long_dispersion_proc_tB6 \
                                                 => long_dispersion_proc_completed
                long_forecast_tJ             => long_dispersion_proc_tJ \
                                                 => long_dispersion_proc_completed
                long_forecast_tC0             => long_dispersion_proc_tC0 \
                                                 => long_dispersion_proc_completed
                long_forecast_tKA             => long_dispersion_proc_tKA \
                                                 => long_dispersion_proc_completed
                long_forecast_tKE             => long_dispersion_proc_tKE \
                                                 => long_dispersion_proc_completed
                long_forecast_tZG             => long_dispersion_proc_tZG \
                                                 => long_dispersion_proc_completed
                long_forecast_tZC             => long_dispersion_proc_tZC \
                                                 => long_dispersion_proc_completed
                long_forecast_tL             => long_dispersion_proc_tL \
                                                 => long_dispersion_proc_completed
                long_forecast_tN             => long_dispersion_proc_tN \
                                                 => long_dispersion_proc_completed
                long_forecast_tZM             => long_dispersion_proc_tZM \
                                                 => long_dispersion_proc_completed
                long_forecast_tZP             => long_dispersion_proc_tZP \
                                                 => long_dispersion_proc_completed
                long_forecast_tZT             => long_dispersion_proc_tZT \
                                                 => long_dispersion_proc_completed
                long_dispersion_proc_completed      => long_dispersion_archive_forecast  \
                                                 => long_dispersion_prune_forecast    \
                                                 => long_dispersion_housekeep
                long_forecast_end                  => long_local & long_bigleftright
                long_forecast_end                  => long_happyland_ingest
                long_forecast_end                  => long_send_stingray_stingray
                long_forecast_end                  => long_user_hook
                long_verificationmodel_database_induced    => long_sync_verification
           """
        [[[ T06, T18 ]]]
            graph = """
                long_assimilation_look_at_larger                           =>  long_forecast_short
                long_forecast_short => LONG_OBS_PROCESS_LOOK_AT:succeed-all => long_observations_db_stuff_wagtail => long_archive_short => housekeep
                long_forecast_short                           => long_verificationmodel_database_short
                long_forecast_subjob_tC0                           => long_verificationmodel_database_short => long_verificationmodel_database_induced_short
                long_verificationmodel_database_induced_short & brief_verificationmodel_database_induced => housekeep
                long_forecast_short:start                                        \
                                                 => long_forecast_tA       \
                                                 => long_forecast_tB       \
                                                 => long_forecast_tC       \
                                                 => long_forecast_tD       \
                                                 => long_forecast_tE       \
                                                 => long_forecast_tF       \
                                                 => long_forecast_tG       \
                                                 => long_forecast_tH       \
                                                 => long_forecast_tI       \
                                                 => long_forecast_tB0       \
                                                 => long_forecast_tB3       \
                                                 => long_forecast_tB6       \
                                                 => long_forecast_tB9       \
                                                 => long_forecast_tBA       \
                                                 => long_forecast_tBB       \
                                                 => long_forecast_tJ       \
                                                 => long_forecast_tBC       \
                                                 => long_forecast_tBD       \
                                                 => long_forecast_tBE       \
                                                 => long_forecast_tC0       \
                                                 => housekeep
                long_forecast_short                => long_forecast_end
                long_forecast_end & LONG_OBS_PROCESS_LOOK_AT:succeed-all         \
                                                 => long_res_delete
                long_forecast_tA             => long_forecast_subjob_tA     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tA           => long_local_preflight_checks
                long_forecast_subjob_tA           => long_thunderbirds_are_go
                long_forecast_tB             => long_forecast_subjob_tB     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tB           => long_local_preflight_checks
                long_forecast_subjob_tB           => long_thunderbirds_are_go
                long_forecast_tC             => long_forecast_subjob_tC     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tC           => long_local_preflight_checks
                long_forecast_subjob_tC           => long_thunderbirds_are_go
                long_forecast_tD             => long_forecast_subjob_tD     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tD           => long_local_preflight_checks
                long_forecast_subjob_tD           => long_thunderbirds_are_go
                long_forecast_tE             => long_forecast_subjob_tE     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tE           => long_local_preflight_checks
                long_forecast_subjob_tE           => long_thunderbirds_are_go
                long_forecast_tF             => long_forecast_subjob_tF     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tF           => long_local_preflight_checks
                long_forecast_subjob_tF           => long_thunderbirds_are_go
                long_forecast_tG             => long_forecast_subjob_tG     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tG           => long_local_preflight_checks
                long_forecast_subjob_tG           => long_thunderbirds_are_go
                long_forecast_tH             => long_forecast_subjob_tH     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tH           => long_local_preflight_checks
                long_forecast_subjob_tH           => long_thunderbirds_are_go
                long_forecast_tI             => long_forecast_subjob_tI     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tI           => long_local_preflight_checks
                long_forecast_subjob_tI           => long_thunderbirds_are_go
                long_forecast_tB0             => long_forecast_subjob_tB0     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tB0           => long_local_preflight_checks
                long_forecast_subjob_tB0           => long_thunderbirds_are_go
                long_forecast_tB3             => long_forecast_subjob_tB3     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tB3           => long_local_preflight_checks
                long_forecast_subjob_tB3           => long_thunderbirds_are_go
                long_forecast_tB6             => long_forecast_subjob_tB6     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tB6           => long_local_preflight_checks
                long_forecast_subjob_tB6           => long_thunderbirds_are_go
                long_forecast_tB9             => long_forecast_subjob_tB9     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tB9           => long_local_preflight_checks
                long_forecast_subjob_tB9           => long_thunderbirds_are_go
                long_forecast_tBA             => long_forecast_subjob_tBA     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tBA           => long_local_preflight_checks
                long_forecast_subjob_tBA           => long_thunderbirds_are_go
                long_forecast_tBB             => long_forecast_subjob_tBB     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tBB           => long_local_preflight_checks
                long_forecast_subjob_tBB           => long_thunderbirds_are_go
                long_forecast_tJ             => long_forecast_subjob_tJ     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tJ           => long_local_preflight_checks
                long_forecast_subjob_tJ           => long_thunderbirds_are_go
                long_forecast_tBC             => long_forecast_subjob_tBC     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tBC           => long_thunderbirds_are_go
                long_forecast_tBD             => long_forecast_subjob_tBD     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tBD           => long_thunderbirds_are_go
                long_forecast_tBE             => long_forecast_subjob_tBE     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tBE           => long_thunderbirds_are_go
                long_forecast_tC0             => long_forecast_subjob_tC0     \
                                                 => long_bigleftright               \
                                                  & long_sync_happy            \
                                                  & long_archive_short
                long_forecast_subjob_tC0           => long_thunderbirds_are_go
                long_forecast_tF             => long_dispersion_tF          \
                                                 => long_dispersion_clock
                long_forecast_tB6             => long_dispersion_tB6          \
                                                 => long_dispersion_clock
                long_forecast_tBD             => long_dispersion_tBD          \
                                                 => long_dispersion_clock
                long_dispersion_clock                     => housekeep
                long_forecast_tD             => long_dispersion_proc_tD \
                                                 => long_dispersion_proc_completed
                long_forecast_tH             => long_dispersion_proc_tH \
                                                 => long_dispersion_proc_completed
                long_forecast_tB6             => long_dispersion_proc_tB6 \
                                                 => long_dispersion_proc_completed
                long_dispersion_proc_completed      => long_dispersion_prune_forecast    \
                                                 => long_dispersion_housekeep
                long_forecast_end                  => long_bigleftright
                long_forecast_end                  => long_happyland_ingest
                long_forecast_end                  => long_send_stingray_stingray
                long_forecast_end                  => long_user_hook
                long_verificationmodel_database_induced_short => long_sync_verification
            """
        [[[ T00, T06, T12, T18 ]]]
            graph = """
                long_start[-PT6H] => long_start
                brief_start[-PT6H] => brief_start
                brief_forecast_redo_ls_little[-PT6H]   => long_assimilation_look_at_little & brief_assimilation_look_at_little
                brief_forecast_redo_ls_larger[-PT6H]   => long_assimilation_look_at_larger & brief_assimilation_look_at_larger
                brief_forecast_redo_ls_screen[-PT6H] => brief_assimilation_look_at_screen
                brief_start => brief_wagtail_aintree_filter & brief_observations_background_atmos & BRIEF_OBSERVATIONS_PROCESS_BACKGROUND
                long_start => long_forecast_create_zap_little & long_forecast_create_zap_larger & long_observations_background_atmos & LONG_OBS_PROCESS_BACKGROUND
                long_forecast_create_zap_little => long_assimilation_create_zap_little => long_assimilation_look_at_little & brief_assimilation_look_at_little
                long_forecast_create_zap_larger => long_assimilation_create_zap_larger => long_assimilation_look_at_larger & brief_assimilation_look_at_larger
                brief_wagtail_aintree_filter    => brief_wagtail_forecast_landsim           \
                                      => brief_wagtail_landsim  \
                                      => brief_wagtail_filter
                long_observations_background_atmos                => LONG_OBS_PROCESS_BACKGROUND:succeed-all                     \
                                                 => long_assimilation_look_at_little                               \
                                                 => long_assimilation_look_at_larger
                brief_observations_background_atmos                => BRIEF_OBSERVATIONS_PROCESS_BACKGROUND:succeed-all                     \
                                                 => brief_assimilation_look_at_little                               \
                                                 => brief_assimilation_look_at_larger
                brief_forecast[-PT6H] => brief_wagtail_aintree_filter & brief_observations_background_atmos & long_observations_background_atmos \
                                         & LONG_OBS_PROCESS_BACKGROUND & BRIEF_OBSERVATIONS_PROCESS_BACKGROUND
                brief_assimilation_look_at_larger & brief_wagtail_filter => brief_forecast
                brief_forecast                      => brief_observations_process_look_at_barn_owl \
                                                 => brief_observations_db_stuff_barn_owl => brief_archive
                brief_observations_process_look_at_barn_owl => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_avocet \
                                                 => brief_observations_db_stuff_avocet => brief_archive
                brief_observations_process_look_at_avocet => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_chaffinch \
                                                 => brief_observations_db_stuff_chaffinch => brief_archive
                brief_observations_process_look_at_chaffinch => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_egret \
                                                 => brief_observations_db_stuff_egret => brief_archive
                brief_observations_process_look_at_egret => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_dipper \
                                                 => brief_observations_db_stuff_dipper => brief_archive
                brief_observations_process_look_at_dipper => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_gannet \
                                                 => brief_observations_db_stuff_gannet => brief_archive
                brief_observations_process_look_at_gannet => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_fulmar \
                                                 => brief_observations_db_stuff_fulmar => brief_archive
                brief_observations_process_look_at_fulmar => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_house_martin \
                                                 => brief_observations_db_stuff_house_martin => brief_archive
                brief_observations_process_look_at_house_martin => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_iceland_gull \
                                                 => brief_observations_db_stuff_iceland_gull => brief_archive
                brief_observations_process_look_at_iceland_gull => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_jackdaw \
                                                 => brief_observations_db_stuff_jackdaw => brief_archive
                brief_observations_process_look_at_jackdaw => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_kestrel \
                                                 => brief_observations_db_stuff_kestrel => brief_archive
                brief_observations_process_look_at_kestrel => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_lapwing \
                                                 => brief_observations_db_stuff_lapwing => brief_archive
                brief_observations_process_look_at_lapwing => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_mallard \
                                                 => brief_observations_db_stuff_mallard => brief_archive
                brief_observations_process_look_at_mallard => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_nightjar \
                                                 => brief_observations_db_stuff_nightjar => brief_archive
                brief_observations_process_look_at_nightjar => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_osprey \
                                                 => brief_observations_db_stuff_osprey => brief_archive
                brief_observations_process_look_at_osprey => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_pheasant \
                                                 => brief_observations_db_stuff_pheasant => brief_archive
                brief_observations_process_look_at_pheasant => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_quail \
                                                 => brief_observations_db_stuff_quail => brief_archive
                brief_observations_process_look_at_quail => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_raven \
                                                 => brief_observations_db_stuff_raven => brief_archive
                brief_observations_process_look_at_raven => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_shelduck \
                                                 => brief_observations_db_stuff_shelduck => brief_archive
                brief_observations_process_look_at_shelduck => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_teal \
                                                 => brief_observations_db_stuff_teal => brief_archive
                brief_observations_process_look_at_teal => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_velvet_scoter \
                                                 => brief_observations_db_stuff_velvet_scoter => brief_archive
                brief_observations_process_look_at_velvet_scoter => brief_res_delete
                brief_forecast                      => brief_observations_process_look_at_wagtail \
                                                 => brief_observations_db_stuff_wagtail => brief_archive
                brief_observations_process_look_at_wagtail => brief_res_delete
                brief_forecast                      => brief_observations_merge_look_at
                brief_forecast                      => brief_verificationmodel_database
                brief_forecast                      => brief_forecast_redo_ls_little & brief_forecast_redo_ls_larger \
                                                  & brief_forecast_redo_ls_screen                        \
                                                 => brief_archive
                brief_observations_background_atmos                => brief_observations_merge_background
                brief_observations_background_atmos                => brief_observations_process_screen                          \
                                                 => brief_assimilation_look_at_screen                             \
                                                 => brief_wagtail_filter
                brief_observations_merge_background         => brief_observations_merge_look_at  => housekeep
                brief_forecast_subjob_tC                 => brief_verificationmodel_database => brief_verificationmodel_database_induced
                brief_archive                       => housekeep
                LONG_OBS_PROCESS_BACKGROUND:succeed-all => long_bogus_listing
                BRIEF_OBSERVATIONS_PROCESS_BACKGROUND:succeed-all => brief_bogus_listing
                brief_forecast:start                                        \
                                                 => brief_forecast_tA       \
                                                 => brief_forecast_tB       \
                                                 => brief_forecast_tC       \
                                                 => brief_forecast_tD       \
                                                 => housekeep
                brief_forecast                      => brief_forecast_end            \
                                                 => brief_res_delete
                brief_forecast_tA             => brief_forecast_subjob_tA     \
                                                 => brief_archive
                brief_forecast_tB             => brief_forecast_subjob_tB     \
                                                 => brief_archive
                brief_forecast_tC             => brief_forecast_subjob_tC     \
                                                 => brief_archive
                brief_forecast_tD             => brief_forecast_subjob_tD     \
                                                 => brief_archive
                brief_forecast_end                  => brief_user_hook
                long_forecast_tC            => long_sync_forecast_tC  => housekeep
                long_forecast_tJ           => long_sync_forecast_tJ => housekeep
                long_forecast_end           => long_sync_forecast     => housekeep
                long_forecast_end           => long_sync_main     => housekeep
                long_sync_happy & long_sync_verification                 => housekeep
                brief_forecast_end & brief_forecast_tB \
                                          => brief_sync_forecast     => housekeep
                brief_forecast_redo_ls_little & brief_forecast_redo_ls_larger & brief_forecast_redo_ls_screen \
                                          => brief_sync_main     => housekeep
                brief_forecast_end           => brief_sync_happy       => housekeep
                brief_verificationmodel_database_induced  => brief_sync_verification      => housekeep
            """
[runtime]
    [[GL]]
    [[LONG]]
        inherit = None, GL
    [[BRIEF]]
        inherit = None, GL
    [[COLD_START]]
        inherit = GL
    [[OBS_PARALLEL]]
        inherit = HPC, CORETYPE_PARALLEL
    [[OBS_SHARED]]
        inherit = HPC, CORETYPE_SHARED
    [[SURFACE_PARALLEL]]
        inherit = HPC, CORETYPE_PARALLEL
    [[FORECAST_PARALLEL]]
        inherit = HPC, CORETYPE_PARALLEL
    [[ASSIMILATION_PARALLEL]]
        inherit = HPC, CORETYPE_PARALLEL
    [[VERIFICATIONMODEL_SHARED]]
        inherit = HPC, CORETYPE_SHARED
    [[LONG_OBS]]
        inherit = LONG, INSTALL_DIAG
    [[BRIEF_OBS]]
        inherit = BRIEF, INSTALL_DIAG
    [[LONG_OBS_PROCESS_BACKGROUND]]
        inherit = LONG_OBS, LONG_OBS_ENVIRONMENT, LONG_RES
    [[BRIEF_OBSERVATIONS_PROCESS_BACKGROUND]]
        inherit = BRIEF_OBS, BRIEF_OBS_ENVIRONMENT, BRIEF_RES
    [[LONG_OBS_PROCESS_LOOK_AT]]
        inherit = LONG_OBS, LONG_OBS_ENVIRONMENT, LONG_RES
    [[BRIEF_OBS_PROCESS_LOOK_AT]]
        inherit = BRIEF_OBS, BRIEF_OBS_ENVIRONMENT, BRIEF_RES
    [[LONG_OBS_DB_STUFF]]
        inherit = LONG_OBS, LONG_OBS_ENVIRONMENT, LONG_HPC
    [[BRIEF_OBS_DB_STUFF]]
        inherit = BRIEF_OBS, BRIEF_OBS_ENVIRONMENT, BRIEF_HPC
    [[LONG_OBS_ENVIRONMENT]]
    [[BRIEF_OBS_ENVIRONMENT]]
    [[BRIEF_SURFACE_LANDSIM]]
        inherit = BRIEF
    [[BRIEF_SURFACE]]
        inherit = BRIEF
    [[BRIEF_FORECAST]]
        inherit = BRIEF, BRIEF_RES
    [[LONG_FORECAST]]
        inherit = LONG, LONG_RES
    [[_MODEL]]
    [[LONG_FORECAST_SHORT]]
    [[LONG_FORECAST_LONG]]
    [[LONGBRIEF_FORECAST_REDO]]
    [[LONGBRIEF_FORECAST_CREATE_ZAP]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[LONGBRIEF_FORECAST_CREATE_ZAP_LITTLE]]
        inherit = LONGBRIEF_FORECAST_CREATE_ZAP
    [[LONGBRIEF_FORECAST_CREATE_ZAP_BIGGER]]
        inherit = LONGBRIEF_FORECAST_CREATE_ZAP
    [[LONG_ASSIMILATION_ZAP]]
        inherit = LONG, INSTALL_DIAG, HPC, LONG_HPC
    [[LONGBRIEF_FORECAST_REDO_LS]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[LONGBRIEF_FORECAST_REDO_LS_LITTLE]]
        inherit = LONGBRIEF_FORECAST_REDO_LS
    [[LONGBRIEF_FORECAST_REDO_LS_BIGGER]]
        inherit = LONGBRIEF_FORECAST_REDO_LS
    [[LONGBRIEF_FORECAST_REDO_LS_SCREEN]]
        inherit = LONGBRIEF_FORECAST_REDO_LS
    [[LONG_ASSIMILATION_LOOK_AT]]
        inherit = LONG, INSTALL_DIAG, LONG_RES
    [[BRIEF_ASSIMILATION_LOOK_AT]]
        inherit = BRIEF, INSTALL_DIAG, BRIEF_RES
    [[LONGBRIEF_ASSIMILATION_LOOK_AT_LITTLE]]
    [[LONGBRIEF_ASSIMILATION_LOOK_AT_BIGGER]]
    [[LONG_HPC]]
    [[BRIEF_HPC]]
    [[LONG_RES]]
        inherit = LONG_HPC
    [[BRIEF_RES]]
        inherit = BRIEF_HPC
    [[long_archive_long, long_archive_short]]
        inherit = LONG, ARCHIVE, HPC, LONG_HPC, CORETYPE_SHARED
    [[brief_archive]]
        inherit = BRIEF, ARCHIVE, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[longbrief_install_startdata_cold]]
        inherit = COLD_START, HPC, CORETYPE_SHARED
    [[brief_start]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[long_start]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[long_observations_background_atmos]]
        inherit = LONG_OBS, OBS_PARALLEL, LONG_RES
    [[brief_observations_background_atmos]]
        inherit = BRIEF_OBS, OBS_PARALLEL, BRIEF_RES
    [[brief_observations_process_background_barn_owl]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_barn_owl]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_barn_owl]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_barn_owl]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_barn_owl]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_avocet]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_avocet]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_avocet]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_avocet]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_avocet]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_chaffinch]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_chaffinch]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_chaffinch]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_chaffinch]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_chaffinch]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_egret]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_egret]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_egret]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_egret]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_egret]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_dipper]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_dipper]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_dipper]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_dipper]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_dipper]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_gannet]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_gannet]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_gannet]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_gannet]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_gannet]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_fulmar]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_fulmar]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_fulmar]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_fulmar]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_fulmar]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_house_martin]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_house_martin]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_house_martin]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_house_martin]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_house_martin]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_iceland_gull]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_iceland_gull]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_iceland_gull]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_iceland_gull]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_iceland_gull]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_jackdaw]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_jackdaw]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_jackdaw]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_jackdaw]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_jackdaw]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_kestrel]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_kestrel]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_kestrel]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_kestrel]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_kestrel]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_lapwing]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_lapwing]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_lapwing]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_lapwing]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_lapwing]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_mallard]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_mallard]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_mallard]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_mallard]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_mallard]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_nightjar]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_nightjar]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_nightjar]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_nightjar]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_nightjar]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_osprey]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_osprey]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_osprey]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_osprey]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_osprey]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_pheasant]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_pheasant]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_pheasant]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_pheasant]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_pheasant]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_quail]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_quail]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_quail]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_quail]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_quail]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_raven]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_raven]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_raven]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_raven]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_raven]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_shelduck]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_shelduck]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_shelduck]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_shelduck]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_shelduck]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_teal]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_teal]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_teal]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_teal]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_teal]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_velvet_scoter]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_velvet_scoter]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_velvet_scoter]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_velvet_scoter]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_velvet_scoter]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_background_wagtail]]
        inherit = BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_process_look_at_wagtail]]
        inherit = BRIEF_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_background_wagtail]]
        inherit = LONG_OBS_PROCESS_BACKGROUND, OBS_PARALLEL, RETRY_TASK
    [[long_observations_process_look_at_wagtail]]
        inherit = LONG_OBS_PROCESS_LOOK_AT, OBS_PARALLEL, RETRY_TASK
    [[brief_observations_db_stuff_wagtail]]
        inherit = BRIEF_OBS_DB_STUFF, OBS_SHARED
    [[long_observations_db_stuff_wagtail]]
        inherit = LONG_OBS_DB_STUFF, OBS_SHARED
    [[brief_observations_process_screen]]
        inherit = BRIEF_OBS, BRIEF_OBS_ENVIRONMENT, OBS_PARALLEL, BRIEF_RES
    [[brief_wagtail_filter]]
        inherit = BRIEF_SURFACE, BRIEF_RES, SURFACE_PARALLEL
    [[brief_wagtail_look_at_wagtail_ice]]
        inherit = BRIEF_SURFACE, BRIEF_RES, SURFACE_PARALLEL
    [[brief_wagtail_forecast_landsim]]
        inherit = BRIEF_SURFACE, BRIEF_RES, SURFACE_PARALLEL
    [[brief_wagtail_landsim]]
        inherit = BRIEF_SURFACE_LANDSIM, BRIEF_SURFACE, HPC
    [[brief_wagtail_look_at_snow]]
        inherit = BRIEF_SURFACE, BRIEF_RES, RETRY_TASK, SURFACE_PARALLEL
    [[brief_wagtail_aintree_filter]]
        inherit = BRIEF_SURFACE, BRIEF_RES, RETRY_TASK, SURFACE_PARALLEL
    [[long_forecast_long]]
        inherit = LONG_FORECAST, FORECAST_PARALLEL, LONG_FORECAST_LONG
    [[long_forecast_short]]
        inherit = LONG_FORECAST, FORECAST_PARALLEL, LONG_FORECAST_SHORT
    [[brief_forecast]]
        inherit = BRIEF_FORECAST, FORECAST_PARALLEL, _MODEL
    [[brief_forecast_redo_daily]]
        inherit = BRIEF_FORECAST, FORECAST_PARALLEL, LONGBRIEF_FORECAST_REDO
    [[long_assimilation_look_at_little]]
        inherit = LONG_ASSIMILATION_LOOK_AT, LONGBRIEF_ASSIMILATION_LOOK_AT_LITTLE, ASSIMILATION_PARALLEL
    [[long_assimilation_look_at_larger]]
        inherit = LONG_ASSIMILATION_LOOK_AT, LONGBRIEF_ASSIMILATION_LOOK_AT_BIGGER, ASSIMILATION_PARALLEL
    [[brief_assimilation_look_at_little]]
        inherit = BRIEF_ASSIMILATION_LOOK_AT, LONGBRIEF_ASSIMILATION_LOOK_AT_LITTLE, ASSIMILATION_PARALLEL
    [[brief_assimilation_look_at_larger]]
        inherit = BRIEF_ASSIMILATION_LOOK_AT, LONGBRIEF_ASSIMILATION_LOOK_AT_BIGGER, ASSIMILATION_PARALLEL
    [[brief_assimilation_look_at_screen]]
        inherit = BRIEF_ASSIMILATION_LOOK_AT, ASSIMILATION_PARALLEL
    [[brief_forecast_redo_ls_little]]
        inherit = LONGBRIEF_FORECAST_REDO_LS_LITTLE, HPC, LONGBRIEF_FORECAST_REDO
    [[brief_forecast_redo_ls_larger]]
        inherit = LONGBRIEF_FORECAST_REDO_LS_BIGGER, HPC, LONGBRIEF_FORECAST_REDO
    [[brief_forecast_redo_ls_screen]]
        inherit = LONGBRIEF_FORECAST_REDO_LS_SCREEN, HPC, LONGBRIEF_FORECAST_REDO
    [[long_forecast_create_zap_little]]
        inherit = LONGBRIEF_FORECAST_CREATE_ZAP_LITTLE
    [[long_forecast_create_zap_larger]]
        inherit = LONGBRIEF_FORECAST_CREATE_ZAP_BIGGER
    [[long_assimilation_create_zap_little]]
        inherit = LONG_ASSIMILATION_ZAP
    [[long_assimilation_create_zap_larger]]
        inherit = LONG_ASSIMILATION_ZAP
    [[long_verificationmodel_database]]
        inherit = LONG, LONG_HPC, VERIFICATIONMODEL_SHARED
    [[long_verificationmodel_database_short]]
        inherit = LONG, LONG_HPC, VERIFICATIONMODEL_SHARED
    [[brief_verificationmodel_database]]
        inherit = BRIEF, BRIEF_HPC, VERIFICATIONMODEL_SHARED
[runtime]
    [[LONG_FORECAST_TRIGGER]]
        inherit = LONG, HPC, CORETYPE_SHARED
    [[BRIEF_FORECAST_TRIGGER]]
        inherit = BRIEF, HPC, CORETYPE_SHARED
    [[LONG_SUBJOB]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[BRIEF_SUBJOB]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[LONG_DISPERSION]]
        inherit = LONG, HPC, LONG_HPC
    [[LONG_DISPERSION_PROC]]
        inherit = LONG, HPC, LONG_HPC
    [[LONG_DISPERSION_ARCHIVING]]
        inherit = LONG, HPC, LONG_HPC
    [[LONG_DISPERSION_HOUSEKEEPING]]
        inherit = LONG, HPC, LONG_HPC
    [[LONG_MIRROR]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[BRIEF_MIRROR]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[long_local_preflight_checks, long_local]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[long_bigleftright]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[long_happyland_ingest]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[long_bogus_listing]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[brief_bogus_listing]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[long_dispersion_tF]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tB6]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tBD]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tKA]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tL]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tZC]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tZG]]
        inherit = LONG_DISPERSION
    [[long_dispersion_tZM]]
        inherit = LONG_DISPERSION
    [[long_dispersion_clock]]
        inherit = LONG_DISPERSION
    [[long_dispersion_proc_tD]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tH]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tB6]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tJ]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tC0]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tKA]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tKE]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tZG]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tZC]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tL]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tN]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tZM]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tZP]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_tZT]]
        inherit = LONG_DISPERSION_PROC
    [[long_dispersion_proc_completed]]
        inherit = LONG_DISPERSION_HOUSEKEEPING
    [[long_dispersion_archive_prep]]
        inherit = LONG_DISPERSION_ARCHIVING
    [[long_dispersion_archive]]
        inherit = LONG_DISPERSION_ARCHIVING
    [[long_dispersion_archive_forecast]]
        inherit = LONG, LOCAL
    [[long_dispersion_prune_forecast]]
        inherit = LONG_DISPERSION_HOUSEKEEPING
    [[long_dispersion_housekeep]]
        inherit = LONG_DISPERSION_HOUSEKEEPING
    [[long_thunderbirds_are_go]]
        inherit = LONG, HPC, LONG_HPC
    [[long_send_stingray_stingray]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[long_sync_main, long_sync_forecast, long_sync_verification]]
        inherit = LONG_MIRROR
    [[long_sync_happy]]
        inherit = LONG_MIRROR
    [[long_sync_forecast_tC]]
        inherit = LONG_MIRROR
    [[long_sync_forecast_tJ]]
        inherit = LONG_MIRROR
    [[brief_sync_main, brief_sync_forecast, brief_sync_verification]]
        inherit = BRIEF_MIRROR
    [[brief_sync_happy]]
        inherit = BRIEF_MIRROR
    [[brief_hpc_backup_daily]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[long_user_hook]]
        inherit = LONG, HPC, LONG_HPC, CORETYPE_SHARED
    [[brief_user_hook]]
        inherit = BRIEF, HPC, BRIEF_HPC, CORETYPE_SHARED
    [[long_verificationmodel_database_induced]]
        inherit = LONG, VERIFICATIONMODEL_SHARED
    [[long_verificationmodel_database_induced_short]]
        inherit = LONG, VERIFICATIONMODEL_SHARED
    [[brief_verificationmodel_database_induced]]
        inherit = BRIEF, VERIFICATIONMODEL_SHARED
    [[brief_observations_merge_background]]
        inherit = BRIEF_OBS, OBS_PARALLEL, BRIEF_HPC
    [[brief_observations_merge_look_at]]
        inherit = BRIEF_OBS, OBS_PARALLEL, BRIEF_HPC
    [[brief_observations_wagtail_background, brief_observations_wagtail_look_at]]
        inherit = BRIEF_OBS, OBS_PARALLEL, BRIEF_HPC
    [[brief_observations_process_wagtail_background]]
        inherit = BRIEF_OBS, OBS_PARALLEL, BRIEF_HPC
    [[brief_observations_process_wagtail_look_at]]
        inherit = BRIEF_OBS, OBS_PARALLEL, BRIEF_HPC
    [[long_start_00, long_start_06, long_start_12, long_start_18]]
        inherit = LONG, OS_START
    [[brief_start_00, brief_start_06, brief_start_12, brief_start_18]]
        inherit = BRIEF, OS_START
    [[long_res_create]]
        inherit = OS_RES_CREATE, LONG_HPC
    [[brief_res_create]]
        inherit = OS_RES_CREATE, BRIEF_HPC
    [[long_res_delete]]
        inherit = OS_RES_DELETE, LONG_HPC
    [[brief_res_delete]]
        inherit = OS_RES_DELETE, BRIEF_HPC
    [[long_forecast_tA]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tB]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tC]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tD]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tE]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tF]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tG]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tH]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tI]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tB0]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tB3]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tB6]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tB9]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tBA]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tBB]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tJ]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tBC]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tBD]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tBE]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tC0]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tC3]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tC6]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tK]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tKA]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tKB]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tKC]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tKD]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tKE]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tKF]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tL]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZF]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZG]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZH]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZA]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZB]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZC]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tM]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZD]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZE]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tN]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZI]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZJ]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZK]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZM]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZN]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZO]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tO]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZP]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZQ]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZR]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZS]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[long_forecast_tZT]]
        inherit = LONG_FORECAST_TRIGGER, LONG_HPC
    [[brief_forecast_tA]]
        inherit = BRIEF_FORECAST_TRIGGER, BRIEF_HPC
    [[brief_forecast_tB]]
        inherit = BRIEF_FORECAST_TRIGGER, BRIEF_HPC
    [[brief_forecast_tC]]
        inherit = BRIEF_FORECAST_TRIGGER, BRIEF_HPC
    [[brief_forecast_tD]]
        inherit = BRIEF_FORECAST_TRIGGER, BRIEF_HPC
    [[long_forecast_end]]
        inherit = LONG_FORECAST_TRIGGER, LOCAL
    [[brief_forecast_end]]
        inherit = BRIEF_FORECAST_TRIGGER, LOCAL
    [[long_forecast_subjob_tA]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tB]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tC]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tD]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tE]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tF]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tG]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tH]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tI]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tB0]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tB3]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tB6]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tB9]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tBA]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tBB]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tJ]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tBC]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tBD]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tBE]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tC0]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tC3]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tC6]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tK]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tKA]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tKB]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tKC]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tKD]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tKE]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tKF]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZF]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZA]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZB]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZC]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tM]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZD]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZE]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tL]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZG]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZH]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tN]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZI]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZJ]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZK]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZM]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZN]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZO]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tO]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZP]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZQ]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZR]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZS]]
        inherit = LONG_SUBJOB
    [[long_forecast_subjob_tZT]]
        inherit = LONG_SUBJOB
    [[brief_forecast_subjob_tA]]
        inherit = BRIEF_SUBJOB
    [[brief_forecast_subjob_tB]]
        inherit = BRIEF_SUBJOB
    [[brief_forecast_subjob_tC]]
        inherit = BRIEF_SUBJOB
    [[brief_forecast_subjob_tD]]
        inherit = BRIEF_SUBJOB
[scheduling]
    [[queues]]
        [[[ENSEMBLELIMIT]]]
            limit = 3
            members = ENSEMBLE_FORECAST_SHRT
        [[[ENSEMBLEOBSLIMIT]]]
            limit = 20
            members = ENSEMBLE_OBS
    [[dependencies]]
        [[[ T00 ]]]
            graph = """
                ensemble_res_create & ensembles_res_create => ensemble_start_00  => ensemble_start
            """
        [[[ T06 ]]]
            graph = """
                ensemble_res_create & ensembles_res_create => ensemble_start_06  => ensemble_start
            """
        [[[ T12 ]]]
            graph = """
                ensemble_res_create & ensembles_res_create => ensemble_start_12  => ensemble_start
            """
        [[[ T18 ]]]
            graph = """
                ensemble_res_create & ensembles_res_create => ensemble_start_18  => ensemble_start
            """
        [[[ T00, T12 ]]]
            graph = """
                  ensemble_ens_wiggle              => ensemble_forecast_long_001
                  ensemble_forecast_long_001      => ensemble_verificationmodel_database
                  ensemble_forecast_long_001      => ensemble_res_delete
                ensemble_forecast_long_001        => ensemble_forecast_end
                ensemble_forecast_long_001:start \
                                                 => ensemble_forecast_001_tC \
                                                 => ensemble_forecast_001_tI \
                                                 => ensemble_forecast_001_tJ \
                                                 => ensemble_forecast_001_tK \
                                                 => ensemble_forecast_001_tL \
                                                 => ensemble_forecast_001_tM \
                                                 => ensemble_forecast_001_tN \
                                                 => ensemble_forecast_001_tO \
                                                 => ensemble_forecast_001_tP \
                                                 => housekeep
                ensemble_forecast_001_tC      => ensemble_forecast_subjob_001_tC \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tI      => ensemble_forecast_subjob_001_tI \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tJ      => ensemble_forecast_subjob_001_tJ \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tK      => ensemble_forecast_subjob_001_tK \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tL      => ensemble_forecast_subjob_001_tL \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tM      => ensemble_forecast_subjob_001_tM \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tN      => ensemble_forecast_subjob_001_tN \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tO      => ensemble_forecast_subjob_001_tO \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_001_tP      => ensemble_forecast_subjob_001_tP \
                                                 => ensemble_forecast_subjob_001_sdfk & ensemble_forecast_subjob_001_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_001 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_001        => ensemble_forecast_subjob_001_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_001_tK           => ensemble_forecast_all_tK
                ensemble_forecast_001_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_002
                  ensemble_forecast_long_002      => ensemble_verificationmodel_database
                  ensemble_forecast_long_002      => ensemble_res_delete
                ensemble_forecast_long_002        => ensemble_forecast_end
                ensemble_forecast_long_002:start \
                                                 => ensemble_forecast_002_tC \
                                                 => ensemble_forecast_002_tI \
                                                 => ensemble_forecast_002_tJ \
                                                 => ensemble_forecast_002_tK \
                                                 => ensemble_forecast_002_tL \
                                                 => ensemble_forecast_002_tM \
                                                 => ensemble_forecast_002_tN \
                                                 => ensemble_forecast_002_tO \
                                                 => ensemble_forecast_002_tP \
                                                 => housekeep
                ensemble_forecast_002_tC      => ensemble_forecast_subjob_002_tC \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tI      => ensemble_forecast_subjob_002_tI \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tJ      => ensemble_forecast_subjob_002_tJ \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tK      => ensemble_forecast_subjob_002_tK \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tL      => ensemble_forecast_subjob_002_tL \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tM      => ensemble_forecast_subjob_002_tM \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tN      => ensemble_forecast_subjob_002_tN \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tO      => ensemble_forecast_subjob_002_tO \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_002_tP      => ensemble_forecast_subjob_002_tP \
                                                 => ensemble_forecast_subjob_002_sdfk & ensemble_forecast_subjob_002_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_002 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_002        => ensemble_forecast_subjob_002_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_002_tK           => ensemble_forecast_all_tK
                ensemble_forecast_002_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_003
                  ensemble_forecast_long_003      => ensemble_verificationmodel_database
                  ensemble_forecast_long_003      => ensemble_res_delete
                ensemble_forecast_long_003        => ensemble_forecast_end
                ensemble_forecast_long_003:start \
                                                 => ensemble_forecast_003_tC \
                                                 => ensemble_forecast_003_tI \
                                                 => ensemble_forecast_003_tJ \
                                                 => ensemble_forecast_003_tK \
                                                 => ensemble_forecast_003_tL \
                                                 => ensemble_forecast_003_tM \
                                                 => ensemble_forecast_003_tN \
                                                 => ensemble_forecast_003_tO \
                                                 => ensemble_forecast_003_tP \
                                                 => housekeep
                ensemble_forecast_003_tC      => ensemble_forecast_subjob_003_tC \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tI      => ensemble_forecast_subjob_003_tI \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tJ      => ensemble_forecast_subjob_003_tJ \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tK      => ensemble_forecast_subjob_003_tK \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tL      => ensemble_forecast_subjob_003_tL \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tM      => ensemble_forecast_subjob_003_tM \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tN      => ensemble_forecast_subjob_003_tN \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tO      => ensemble_forecast_subjob_003_tO \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_003_tP      => ensemble_forecast_subjob_003_tP \
                                                 => ensemble_forecast_subjob_003_sdfk & ensemble_forecast_subjob_003_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_003 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_003        => ensemble_forecast_subjob_003_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_003_tK           => ensemble_forecast_all_tK
                ensemble_forecast_003_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_004
                  ensemble_forecast_long_004      => ensemble_verificationmodel_database
                  ensemble_forecast_long_004      => ensemble_res_delete
                ensemble_forecast_long_004        => ensemble_forecast_end
                ensemble_forecast_long_004:start \
                                                 => ensemble_forecast_004_tC \
                                                 => ensemble_forecast_004_tI \
                                                 => ensemble_forecast_004_tJ \
                                                 => ensemble_forecast_004_tK \
                                                 => ensemble_forecast_004_tL \
                                                 => ensemble_forecast_004_tM \
                                                 => ensemble_forecast_004_tN \
                                                 => ensemble_forecast_004_tO \
                                                 => ensemble_forecast_004_tP \
                                                 => housekeep
                ensemble_forecast_004_tC      => ensemble_forecast_subjob_004_tC \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tI      => ensemble_forecast_subjob_004_tI \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tJ      => ensemble_forecast_subjob_004_tJ \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tK      => ensemble_forecast_subjob_004_tK \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tL      => ensemble_forecast_subjob_004_tL \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tM      => ensemble_forecast_subjob_004_tM \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tN      => ensemble_forecast_subjob_004_tN \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tO      => ensemble_forecast_subjob_004_tO \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_004_tP      => ensemble_forecast_subjob_004_tP \
                                                 => ensemble_forecast_subjob_004_sdfk & ensemble_forecast_subjob_004_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_004 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_004        => ensemble_forecast_subjob_004_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_004_tK           => ensemble_forecast_all_tK
                ensemble_forecast_004_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_005
                  ensemble_forecast_long_005      => ensemble_verificationmodel_database
                  ensemble_forecast_long_005      => ensemble_res_delete
                ensemble_forecast_long_005        => ensemble_forecast_end
                ensemble_forecast_long_005:start \
                                                 => ensemble_forecast_005_tC \
                                                 => ensemble_forecast_005_tI \
                                                 => ensemble_forecast_005_tJ \
                                                 => ensemble_forecast_005_tK \
                                                 => ensemble_forecast_005_tL \
                                                 => ensemble_forecast_005_tM \
                                                 => ensemble_forecast_005_tN \
                                                 => ensemble_forecast_005_tO \
                                                 => ensemble_forecast_005_tP \
                                                 => housekeep
                ensemble_forecast_005_tC      => ensemble_forecast_subjob_005_tC \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tI      => ensemble_forecast_subjob_005_tI \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tJ      => ensemble_forecast_subjob_005_tJ \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tK      => ensemble_forecast_subjob_005_tK \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tL      => ensemble_forecast_subjob_005_tL \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tM      => ensemble_forecast_subjob_005_tM \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tN      => ensemble_forecast_subjob_005_tN \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tO      => ensemble_forecast_subjob_005_tO \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_005_tP      => ensemble_forecast_subjob_005_tP \
                                                 => ensemble_forecast_subjob_005_sdfk & ensemble_forecast_subjob_005_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_005 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_005        => ensemble_forecast_subjob_005_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_005_tK           => ensemble_forecast_all_tK
                ensemble_forecast_005_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_006
                  ensemble_forecast_long_006      => ensemble_verificationmodel_database
                  ensemble_forecast_long_006      => ensemble_res_delete
                ensemble_forecast_long_006        => ensemble_forecast_end
                ensemble_forecast_long_006:start \
                                                 => ensemble_forecast_006_tC \
                                                 => ensemble_forecast_006_tI \
                                                 => ensemble_forecast_006_tJ \
                                                 => ensemble_forecast_006_tK \
                                                 => ensemble_forecast_006_tL \
                                                 => ensemble_forecast_006_tM \
                                                 => ensemble_forecast_006_tN \
                                                 => ensemble_forecast_006_tO \
                                                 => ensemble_forecast_006_tP \
                                                 => housekeep
                ensemble_forecast_006_tC      => ensemble_forecast_subjob_006_tC \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tI      => ensemble_forecast_subjob_006_tI \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tJ      => ensemble_forecast_subjob_006_tJ \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tK      => ensemble_forecast_subjob_006_tK \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tL      => ensemble_forecast_subjob_006_tL \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tM      => ensemble_forecast_subjob_006_tM \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tN      => ensemble_forecast_subjob_006_tN \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tO      => ensemble_forecast_subjob_006_tO \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_006_tP      => ensemble_forecast_subjob_006_tP \
                                                 => ensemble_forecast_subjob_006_sdfk & ensemble_forecast_subjob_006_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_006 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_006        => ensemble_forecast_subjob_006_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_006_tK           => ensemble_forecast_all_tK
                ensemble_forecast_006_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_007
                  ensemble_forecast_long_007      => ensemble_verificationmodel_database
                  ensemble_forecast_long_007      => ensemble_res_delete
                ensemble_forecast_long_007        => ensemble_forecast_end
                ensemble_forecast_long_007:start \
                                                 => ensemble_forecast_007_tC \
                                                 => ensemble_forecast_007_tI \
                                                 => ensemble_forecast_007_tJ \
                                                 => ensemble_forecast_007_tK \
                                                 => ensemble_forecast_007_tL \
                                                 => ensemble_forecast_007_tM \
                                                 => ensemble_forecast_007_tN \
                                                 => ensemble_forecast_007_tO \
                                                 => ensemble_forecast_007_tP \
                                                 => housekeep
                ensemble_forecast_007_tC      => ensemble_forecast_subjob_007_tC \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tI      => ensemble_forecast_subjob_007_tI \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tJ      => ensemble_forecast_subjob_007_tJ \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tK      => ensemble_forecast_subjob_007_tK \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tL      => ensemble_forecast_subjob_007_tL \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tM      => ensemble_forecast_subjob_007_tM \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tN      => ensemble_forecast_subjob_007_tN \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tO      => ensemble_forecast_subjob_007_tO \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_007_tP      => ensemble_forecast_subjob_007_tP \
                                                 => ensemble_forecast_subjob_007_sdfk & ensemble_forecast_subjob_007_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_007 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_007        => ensemble_forecast_subjob_007_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_007_tK           => ensemble_forecast_all_tK
                ensemble_forecast_007_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_008
                  ensemble_forecast_long_008      => ensemble_verificationmodel_database
                  ensemble_forecast_long_008      => ensemble_res_delete
                ensemble_forecast_long_008        => ensemble_forecast_end
                ensemble_forecast_long_008:start \
                                                 => ensemble_forecast_008_tC \
                                                 => ensemble_forecast_008_tI \
                                                 => ensemble_forecast_008_tJ \
                                                 => ensemble_forecast_008_tK \
                                                 => ensemble_forecast_008_tL \
                                                 => ensemble_forecast_008_tM \
                                                 => ensemble_forecast_008_tN \
                                                 => ensemble_forecast_008_tO \
                                                 => ensemble_forecast_008_tP \
                                                 => housekeep
                ensemble_forecast_008_tC      => ensemble_forecast_subjob_008_tC \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tI      => ensemble_forecast_subjob_008_tI \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tJ      => ensemble_forecast_subjob_008_tJ \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tK      => ensemble_forecast_subjob_008_tK \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tL      => ensemble_forecast_subjob_008_tL \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tM      => ensemble_forecast_subjob_008_tM \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tN      => ensemble_forecast_subjob_008_tN \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tO      => ensemble_forecast_subjob_008_tO \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_008_tP      => ensemble_forecast_subjob_008_tP \
                                                 => ensemble_forecast_subjob_008_sdfk & ensemble_forecast_subjob_008_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_008 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_008        => ensemble_forecast_subjob_008_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_008_tK           => ensemble_forecast_all_tK
                ensemble_forecast_008_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_009
                  ensemble_forecast_long_009      => ensemble_verificationmodel_database
                  ensemble_forecast_long_009      => ensemble_res_delete
                ensemble_forecast_long_009        => ensemble_forecast_end
                ensemble_forecast_long_009:start \
                                                 => ensemble_forecast_009_tC \
                                                 => ensemble_forecast_009_tI \
                                                 => ensemble_forecast_009_tJ \
                                                 => ensemble_forecast_009_tK \
                                                 => ensemble_forecast_009_tL \
                                                 => ensemble_forecast_009_tM \
                                                 => ensemble_forecast_009_tN \
                                                 => ensemble_forecast_009_tO \
                                                 => ensemble_forecast_009_tP \
                                                 => housekeep
                ensemble_forecast_009_tC      => ensemble_forecast_subjob_009_tC \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tI      => ensemble_forecast_subjob_009_tI \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tJ      => ensemble_forecast_subjob_009_tJ \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tK      => ensemble_forecast_subjob_009_tK \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tL      => ensemble_forecast_subjob_009_tL \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tM      => ensemble_forecast_subjob_009_tM \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tN      => ensemble_forecast_subjob_009_tN \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tO      => ensemble_forecast_subjob_009_tO \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_009_tP      => ensemble_forecast_subjob_009_tP \
                                                 => ensemble_forecast_subjob_009_sdfk & ensemble_forecast_subjob_009_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_009 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_009        => ensemble_forecast_subjob_009_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_009_tK           => ensemble_forecast_all_tK
                ensemble_forecast_009_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_010
                  ensemble_forecast_long_010      => ensemble_verificationmodel_database
                  ensemble_forecast_long_010      => ensemble_res_delete
                ensemble_forecast_long_010        => ensemble_forecast_end
                ensemble_forecast_long_010:start \
                                                 => ensemble_forecast_010_tC \
                                                 => ensemble_forecast_010_tI \
                                                 => ensemble_forecast_010_tJ \
                                                 => ensemble_forecast_010_tK \
                                                 => ensemble_forecast_010_tL \
                                                 => ensemble_forecast_010_tM \
                                                 => ensemble_forecast_010_tN \
                                                 => ensemble_forecast_010_tO \
                                                 => ensemble_forecast_010_tP \
                                                 => housekeep
                ensemble_forecast_010_tC      => ensemble_forecast_subjob_010_tC \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tI      => ensemble_forecast_subjob_010_tI \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tJ      => ensemble_forecast_subjob_010_tJ \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tK      => ensemble_forecast_subjob_010_tK \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tL      => ensemble_forecast_subjob_010_tL \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tM      => ensemble_forecast_subjob_010_tM \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tN      => ensemble_forecast_subjob_010_tN \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tO      => ensemble_forecast_subjob_010_tO \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_010_tP      => ensemble_forecast_subjob_010_tP \
                                                 => ensemble_forecast_subjob_010_sdfk & ensemble_forecast_subjob_010_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_010 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_010        => ensemble_forecast_subjob_010_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_010_tK           => ensemble_forecast_all_tK
                ensemble_forecast_010_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_011
                  ensemble_forecast_long_011      => ensemble_verificationmodel_database
                  ensemble_forecast_long_011      => ensemble_res_delete
                ensemble_forecast_long_011        => ensemble_forecast_end
                ensemble_forecast_long_011:start \
                                                 => ensemble_forecast_011_tC \
                                                 => ensemble_forecast_011_tI \
                                                 => ensemble_forecast_011_tJ \
                                                 => ensemble_forecast_011_tK \
                                                 => ensemble_forecast_011_tL \
                                                 => ensemble_forecast_011_tM \
                                                 => ensemble_forecast_011_tN \
                                                 => ensemble_forecast_011_tO \
                                                 => ensemble_forecast_011_tP \
                                                 => housekeep
                ensemble_forecast_011_tC      => ensemble_forecast_subjob_011_tC \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tI      => ensemble_forecast_subjob_011_tI \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tJ      => ensemble_forecast_subjob_011_tJ \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tK      => ensemble_forecast_subjob_011_tK \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tL      => ensemble_forecast_subjob_011_tL \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tM      => ensemble_forecast_subjob_011_tM \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tN      => ensemble_forecast_subjob_011_tN \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tO      => ensemble_forecast_subjob_011_tO \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_011_tP      => ensemble_forecast_subjob_011_tP \
                                                 => ensemble_forecast_subjob_011_sdfk & ensemble_forecast_subjob_011_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_011 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_011        => ensemble_forecast_subjob_011_sdfk \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_011_tK           => ensemble_forecast_all_tK
                ensemble_forecast_011_tC            => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_012
                  ensemble_forecast_shrt_012      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_012      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_013
                  ensemble_forecast_shrt_013      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_013      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_014
                  ensemble_forecast_shrt_014      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_014      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_015
                  ensemble_forecast_shrt_015      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_015      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_016
                  ensemble_forecast_shrt_016      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_016      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_017
                  ensemble_forecast_shrt_017      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_017      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_018
                  ensemble_forecast_shrt_018      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_018      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_019
                  ensemble_forecast_shrt_019      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_019      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_020
                  ensemble_forecast_shrt_020      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_020      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_021
                  ensemble_forecast_shrt_021      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_021      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_022
                  ensemble_forecast_shrt_022      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_022      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                ensemble_forecast_end                 => ensemble_res_delete
                ensemble_forecast_end                 => ensemble_user_hook
           """
        [[[ T06, T18 ]]]
            graph = """
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_001
                  ensemble_forecast_shrt_001      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_001      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_002
                  ensemble_forecast_shrt_002      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_002      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_003
                  ensemble_forecast_shrt_003      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_003      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_004
                  ensemble_forecast_shrt_004      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_004      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_005
                  ensemble_forecast_shrt_005      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_005      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_006
                  ensemble_forecast_shrt_006      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_006      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_007
                  ensemble_forecast_shrt_007      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_007      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_008
                  ensemble_forecast_shrt_008      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_008      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_009
                  ensemble_forecast_shrt_009      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_009      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_010
                  ensemble_forecast_shrt_010      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_010      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_011
                  ensemble_forecast_shrt_011      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_011      => ensembles_res_delete            \
                                                  & ensemble_sync_main          \
                                                  & ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_012
                  ensemble_forecast_long_012      => ensemble_verificationmodel_database
                  ensemble_forecast_long_012      => ensemble_res_delete
                  ensemble_forecast_long_012      => ensemble_forecast_end
                  ensemble_forecast_long_012:start \
                                                 => ensemble_forecast_012_tC \
                                                 => ensemble_forecast_012_tI \
                                                 => ensemble_forecast_012_tJ \
                                                 => ensemble_forecast_012_tK \
                                                 => ensemble_forecast_012_tL \
                                                 => ensemble_forecast_012_tM \
                                                 => ensemble_forecast_012_tN \
                                                 => ensemble_forecast_012_tO \
                                                 => ensemble_forecast_012_tP \
                                                 => housekeep
                  ensemble_forecast_012_tC    => ensemble_forecast_subjob_012_tC \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tI    => ensemble_forecast_subjob_012_tI \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tJ    => ensemble_forecast_subjob_012_tJ \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tK    => ensemble_forecast_subjob_012_tK \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tL    => ensemble_forecast_subjob_012_tL \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tM    => ensemble_forecast_subjob_012_tM \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tN    => ensemble_forecast_subjob_012_tN \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tO    => ensemble_forecast_subjob_012_tO \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_012_tP    => ensemble_forecast_subjob_012_tP \
                                                 => ensemble_forecast_subjob_012_sdfk & ensemble_forecast_subjob_012_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_012 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_012      => ensemble_forecast_subjob_012_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_012_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_012_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_013
                  ensemble_forecast_long_013      => ensemble_verificationmodel_database
                  ensemble_forecast_long_013      => ensemble_res_delete
                  ensemble_forecast_long_013      => ensemble_forecast_end
                  ensemble_forecast_long_013:start \
                                                 => ensemble_forecast_013_tC \
                                                 => ensemble_forecast_013_tI \
                                                 => ensemble_forecast_013_tJ \
                                                 => ensemble_forecast_013_tK \
                                                 => ensemble_forecast_013_tL \
                                                 => ensemble_forecast_013_tM \
                                                 => ensemble_forecast_013_tN \
                                                 => ensemble_forecast_013_tO \
                                                 => ensemble_forecast_013_tP \
                                                 => housekeep
                  ensemble_forecast_013_tC    => ensemble_forecast_subjob_013_tC \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tI    => ensemble_forecast_subjob_013_tI \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tJ    => ensemble_forecast_subjob_013_tJ \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tK    => ensemble_forecast_subjob_013_tK \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tL    => ensemble_forecast_subjob_013_tL \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tM    => ensemble_forecast_subjob_013_tM \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tN    => ensemble_forecast_subjob_013_tN \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tO    => ensemble_forecast_subjob_013_tO \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_013_tP    => ensemble_forecast_subjob_013_tP \
                                                 => ensemble_forecast_subjob_013_sdfk & ensemble_forecast_subjob_013_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_013 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_013      => ensemble_forecast_subjob_013_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_013_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_013_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_014
                  ensemble_forecast_long_014      => ensemble_verificationmodel_database
                  ensemble_forecast_long_014      => ensemble_res_delete
                  ensemble_forecast_long_014      => ensemble_forecast_end
                  ensemble_forecast_long_014:start \
                                                 => ensemble_forecast_014_tC \
                                                 => ensemble_forecast_014_tI \
                                                 => ensemble_forecast_014_tJ \
                                                 => ensemble_forecast_014_tK \
                                                 => ensemble_forecast_014_tL \
                                                 => ensemble_forecast_014_tM \
                                                 => ensemble_forecast_014_tN \
                                                 => ensemble_forecast_014_tO \
                                                 => ensemble_forecast_014_tP \
                                                 => housekeep
                  ensemble_forecast_014_tC    => ensemble_forecast_subjob_014_tC \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tI    => ensemble_forecast_subjob_014_tI \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tJ    => ensemble_forecast_subjob_014_tJ \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tK    => ensemble_forecast_subjob_014_tK \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tL    => ensemble_forecast_subjob_014_tL \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tM    => ensemble_forecast_subjob_014_tM \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tN    => ensemble_forecast_subjob_014_tN \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tO    => ensemble_forecast_subjob_014_tO \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_014_tP    => ensemble_forecast_subjob_014_tP \
                                                 => ensemble_forecast_subjob_014_sdfk & ensemble_forecast_subjob_014_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_014 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_014      => ensemble_forecast_subjob_014_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_014_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_014_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_015
                  ensemble_forecast_long_015      => ensemble_verificationmodel_database
                  ensemble_forecast_long_015      => ensemble_res_delete
                  ensemble_forecast_long_015      => ensemble_forecast_end
                  ensemble_forecast_long_015:start \
                                                 => ensemble_forecast_015_tC \
                                                 => ensemble_forecast_015_tI \
                                                 => ensemble_forecast_015_tJ \
                                                 => ensemble_forecast_015_tK \
                                                 => ensemble_forecast_015_tL \
                                                 => ensemble_forecast_015_tM \
                                                 => ensemble_forecast_015_tN \
                                                 => ensemble_forecast_015_tO \
                                                 => ensemble_forecast_015_tP \
                                                 => housekeep
                  ensemble_forecast_015_tC    => ensemble_forecast_subjob_015_tC \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tI    => ensemble_forecast_subjob_015_tI \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tJ    => ensemble_forecast_subjob_015_tJ \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tK    => ensemble_forecast_subjob_015_tK \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tL    => ensemble_forecast_subjob_015_tL \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tM    => ensemble_forecast_subjob_015_tM \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tN    => ensemble_forecast_subjob_015_tN \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tO    => ensemble_forecast_subjob_015_tO \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_015_tP    => ensemble_forecast_subjob_015_tP \
                                                 => ensemble_forecast_subjob_015_sdfk & ensemble_forecast_subjob_015_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_015 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_015      => ensemble_forecast_subjob_015_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_015_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_015_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_016
                  ensemble_forecast_long_016      => ensemble_verificationmodel_database
                  ensemble_forecast_long_016      => ensemble_res_delete
                  ensemble_forecast_long_016      => ensemble_forecast_end
                  ensemble_forecast_long_016:start \
                                                 => ensemble_forecast_016_tC \
                                                 => ensemble_forecast_016_tI \
                                                 => ensemble_forecast_016_tJ \
                                                 => ensemble_forecast_016_tK \
                                                 => ensemble_forecast_016_tL \
                                                 => ensemble_forecast_016_tM \
                                                 => ensemble_forecast_016_tN \
                                                 => ensemble_forecast_016_tO \
                                                 => ensemble_forecast_016_tP \
                                                 => housekeep
                  ensemble_forecast_016_tC    => ensemble_forecast_subjob_016_tC \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tI    => ensemble_forecast_subjob_016_tI \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tJ    => ensemble_forecast_subjob_016_tJ \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tK    => ensemble_forecast_subjob_016_tK \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tL    => ensemble_forecast_subjob_016_tL \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tM    => ensemble_forecast_subjob_016_tM \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tN    => ensemble_forecast_subjob_016_tN \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tO    => ensemble_forecast_subjob_016_tO \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_016_tP    => ensemble_forecast_subjob_016_tP \
                                                 => ensemble_forecast_subjob_016_sdfk & ensemble_forecast_subjob_016_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_016 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_016      => ensemble_forecast_subjob_016_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_016_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_016_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_017
                  ensemble_forecast_long_017      => ensemble_verificationmodel_database
                  ensemble_forecast_long_017      => ensemble_res_delete
                  ensemble_forecast_long_017      => ensemble_forecast_end
                  ensemble_forecast_long_017:start \
                                                 => ensemble_forecast_017_tC \
                                                 => ensemble_forecast_017_tI \
                                                 => ensemble_forecast_017_tJ \
                                                 => ensemble_forecast_017_tK \
                                                 => ensemble_forecast_017_tL \
                                                 => ensemble_forecast_017_tM \
                                                 => ensemble_forecast_017_tN \
                                                 => ensemble_forecast_017_tO \
                                                 => ensemble_forecast_017_tP \
                                                 => housekeep
                  ensemble_forecast_017_tC    => ensemble_forecast_subjob_017_tC \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tI    => ensemble_forecast_subjob_017_tI \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tJ    => ensemble_forecast_subjob_017_tJ \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tK    => ensemble_forecast_subjob_017_tK \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tL    => ensemble_forecast_subjob_017_tL \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tM    => ensemble_forecast_subjob_017_tM \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tN    => ensemble_forecast_subjob_017_tN \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tO    => ensemble_forecast_subjob_017_tO \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_017_tP    => ensemble_forecast_subjob_017_tP \
                                                 => ensemble_forecast_subjob_017_sdfk & ensemble_forecast_subjob_017_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_017 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_017      => ensemble_forecast_subjob_017_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_017_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_017_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_018
                  ensemble_forecast_long_018      => ensemble_verificationmodel_database
                  ensemble_forecast_long_018      => ensemble_res_delete
                  ensemble_forecast_long_018      => ensemble_forecast_end
                  ensemble_forecast_long_018:start \
                                                 => ensemble_forecast_018_tC \
                                                 => ensemble_forecast_018_tI \
                                                 => ensemble_forecast_018_tJ \
                                                 => ensemble_forecast_018_tK \
                                                 => ensemble_forecast_018_tL \
                                                 => ensemble_forecast_018_tM \
                                                 => ensemble_forecast_018_tN \
                                                 => ensemble_forecast_018_tO \
                                                 => ensemble_forecast_018_tP \
                                                 => housekeep
                  ensemble_forecast_018_tC    => ensemble_forecast_subjob_018_tC \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tI    => ensemble_forecast_subjob_018_tI \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tJ    => ensemble_forecast_subjob_018_tJ \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tK    => ensemble_forecast_subjob_018_tK \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tL    => ensemble_forecast_subjob_018_tL \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tM    => ensemble_forecast_subjob_018_tM \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tN    => ensemble_forecast_subjob_018_tN \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tO    => ensemble_forecast_subjob_018_tO \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_018_tP    => ensemble_forecast_subjob_018_tP \
                                                 => ensemble_forecast_subjob_018_sdfk & ensemble_forecast_subjob_018_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_018 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_018      => ensemble_forecast_subjob_018_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_018_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_018_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_019
                  ensemble_forecast_long_019      => ensemble_verificationmodel_database
                  ensemble_forecast_long_019      => ensemble_res_delete
                  ensemble_forecast_long_019      => ensemble_forecast_end
                  ensemble_forecast_long_019:start \
                                                 => ensemble_forecast_019_tC \
                                                 => ensemble_forecast_019_tI \
                                                 => ensemble_forecast_019_tJ \
                                                 => ensemble_forecast_019_tK \
                                                 => ensemble_forecast_019_tL \
                                                 => ensemble_forecast_019_tM \
                                                 => ensemble_forecast_019_tN \
                                                 => ensemble_forecast_019_tO \
                                                 => ensemble_forecast_019_tP \
                                                 => housekeep
                  ensemble_forecast_019_tC    => ensemble_forecast_subjob_019_tC \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tI    => ensemble_forecast_subjob_019_tI \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tJ    => ensemble_forecast_subjob_019_tJ \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tK    => ensemble_forecast_subjob_019_tK \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tL    => ensemble_forecast_subjob_019_tL \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tM    => ensemble_forecast_subjob_019_tM \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tN    => ensemble_forecast_subjob_019_tN \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tO    => ensemble_forecast_subjob_019_tO \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_019_tP    => ensemble_forecast_subjob_019_tP \
                                                 => ensemble_forecast_subjob_019_sdfk & ensemble_forecast_subjob_019_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_019 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_019      => ensemble_forecast_subjob_019_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_019_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_019_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_020
                  ensemble_forecast_long_020      => ensemble_verificationmodel_database
                  ensemble_forecast_long_020      => ensemble_res_delete
                  ensemble_forecast_long_020      => ensemble_forecast_end
                  ensemble_forecast_long_020:start \
                                                 => ensemble_forecast_020_tC \
                                                 => ensemble_forecast_020_tI \
                                                 => ensemble_forecast_020_tJ \
                                                 => ensemble_forecast_020_tK \
                                                 => ensemble_forecast_020_tL \
                                                 => ensemble_forecast_020_tM \
                                                 => ensemble_forecast_020_tN \
                                                 => ensemble_forecast_020_tO \
                                                 => ensemble_forecast_020_tP \
                                                 => housekeep
                  ensemble_forecast_020_tC    => ensemble_forecast_subjob_020_tC \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tI    => ensemble_forecast_subjob_020_tI \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tJ    => ensemble_forecast_subjob_020_tJ \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tK    => ensemble_forecast_subjob_020_tK \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tL    => ensemble_forecast_subjob_020_tL \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tM    => ensemble_forecast_subjob_020_tM \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tN    => ensemble_forecast_subjob_020_tN \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tO    => ensemble_forecast_subjob_020_tO \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_020_tP    => ensemble_forecast_subjob_020_tP \
                                                 => ensemble_forecast_subjob_020_sdfk & ensemble_forecast_subjob_020_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_020 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_020      => ensemble_forecast_subjob_020_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_020_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_020_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_021
                  ensemble_forecast_long_021      => ensemble_verificationmodel_database
                  ensemble_forecast_long_021      => ensemble_res_delete
                  ensemble_forecast_long_021      => ensemble_forecast_end
                  ensemble_forecast_long_021:start \
                                                 => ensemble_forecast_021_tC \
                                                 => ensemble_forecast_021_tI \
                                                 => ensemble_forecast_021_tJ \
                                                 => ensemble_forecast_021_tK \
                                                 => ensemble_forecast_021_tL \
                                                 => ensemble_forecast_021_tM \
                                                 => ensemble_forecast_021_tN \
                                                 => ensemble_forecast_021_tO \
                                                 => ensemble_forecast_021_tP \
                                                 => housekeep
                  ensemble_forecast_021_tC    => ensemble_forecast_subjob_021_tC \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tI    => ensemble_forecast_subjob_021_tI \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tJ    => ensemble_forecast_subjob_021_tJ \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tK    => ensemble_forecast_subjob_021_tK \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tL    => ensemble_forecast_subjob_021_tL \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tM    => ensemble_forecast_subjob_021_tM \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tN    => ensemble_forecast_subjob_021_tN \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tO    => ensemble_forecast_subjob_021_tO \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_021_tP    => ensemble_forecast_subjob_021_tP \
                                                 => ensemble_forecast_subjob_021_sdfk & ensemble_forecast_subjob_021_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_021 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_021      => ensemble_forecast_subjob_021_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_021_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_021_tC          => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_long_022
                  ensemble_forecast_long_022      => ensemble_verificationmodel_database
                  ensemble_forecast_long_022      => ensemble_res_delete
                  ensemble_forecast_long_022      => ensemble_forecast_end
                  ensemble_forecast_long_022:start \
                                                 => ensemble_forecast_022_tC \
                                                 => ensemble_forecast_022_tI \
                                                 => ensemble_forecast_022_tJ \
                                                 => ensemble_forecast_022_tK \
                                                 => ensemble_forecast_022_tL \
                                                 => ensemble_forecast_022_tM \
                                                 => ensemble_forecast_022_tN \
                                                 => ensemble_forecast_022_tO \
                                                 => ensemble_forecast_022_tP \
                                                 => housekeep
                  ensemble_forecast_022_tC    => ensemble_forecast_subjob_022_tC \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tI    => ensemble_forecast_subjob_022_tI \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tJ    => ensemble_forecast_subjob_022_tJ \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tK    => ensemble_forecast_subjob_022_tK \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tL    => ensemble_forecast_subjob_022_tL \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tM    => ensemble_forecast_subjob_022_tM \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tN    => ensemble_forecast_subjob_022_tN \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tO    => ensemble_forecast_subjob_022_tO \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_022_tP    => ensemble_forecast_subjob_022_tP \
                                                 => ensemble_forecast_subjob_022_sdfk & ensemble_forecast_subjob_022_sduv \
                                                 &  ensemble_thunderbirds_are_go_forecast_022 \
                                                 => ensemble_sync_happy
                  ensemble_forecast_long_022      => ensemble_forecast_subjob_022_sdfk   \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                  ensemble_forecast_022_tK         => ensemble_forecast_all_tK
                  ensemble_forecast_022_tC          => ensemble_sync_forecast_tC
                ensemble_forecast_end                 => ensemble_res_delete
                ensemble_forecast_end                 => ensemble_user_hook
            """
        [[[ T00, T06, T12, T18 ]]]
            graph = """
                long_forecast_tA                   => ensemble_start
                ensemble_start[-PT6H] => ensemble_start
                ensemble_forecast_redo_long_look_at[-PT6H]    => ensemble_start                               \
                                              => ensemble_ens_tidy_observations & ensemble_forecast_redo_long_look_at
                LONG_OBS_PROCESS_BACKGROUND:succeed-all => ensemble_ens_tidy_observations
                ensemble_ens_tidy_observations              => ENSEMBLE_OBS
                ENSEMBLE_OBS:succeed-all          => ensemble_ens_filter
                ensemble_verificationmodel_database[-PT6H]:start => ENSEMBLE_OBS
                ensemble_ens_filter & ensemble_forecast_redo_long_look_at => ENSEMBLE_ENS_ADDSURFACES:succeed-all => ensemble_ens_wiggle
                ensemble_forecast_redo_long_look_at         => ensemble_forecast_long_000
                ensemble_forecast_long_000         => ensemble_verificationmodel_database
                ensemble_forecast_long_000         => ensemble_res_delete
                ensemble_forecast_long_000         => ensemble_forecast_end
                ensemble_forecast_long_000:start \
                                                 => ensemble_forecast_000_tC \
                                                 => ensemble_forecast_000_tI \
                                                 => ensemble_forecast_000_tJ \
                                                 => ensemble_forecast_000_tK \
                                                 => ensemble_forecast_000_tL \
                                                 => ensemble_forecast_000_tM \
                                                 => ensemble_forecast_000_tN \
                                                 => ensemble_forecast_000_tO \
                                                 => ensemble_forecast_000_tP \
                                                 => housekeep
                ensemble_forecast_000_tC        => ensemble_forecast_subjob_000_tC \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tI        => ensemble_forecast_subjob_000_tI \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tJ        => ensemble_forecast_subjob_000_tJ \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tK        => ensemble_forecast_subjob_000_tK \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tL        => ensemble_forecast_subjob_000_tL \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tM        => ensemble_forecast_subjob_000_tM \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tN        => ensemble_forecast_subjob_000_tN \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tO        => ensemble_forecast_subjob_000_tO \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_000_tP        => ensemble_forecast_subjob_000_tP \
                                                 => ensemble_forecast_subjob_000_sdfk & ensemble_forecast_subjob_000_sduv \
                                                 &  ensemble_thunderbirds_are_go_updown_or_000 & ensemble_thunderbirds_are_go_forecast_000 \
                                                 => ensemble_sync_happy
                ensemble_forecast_long_000            => ensemble_forecast_subjob_000_sdfk  \
                                                 => ensemble_local & ensemble_downscale & ensemble_subjob_hook
                ensemble_forecast_000_tK             => ensemble_forecast_all_tK
                ensemble_forecast_000_tC              => ensemble_sync_forecast_tC
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_023
                  ensemble_forecast_shrt_023      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_023      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_024
                  ensemble_forecast_shrt_024      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_024      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_025
                  ensemble_forecast_shrt_025      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_025      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_026
                  ensemble_forecast_shrt_026      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_026      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_027
                  ensemble_forecast_shrt_027      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_027      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_028
                  ensemble_forecast_shrt_028      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_028      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_029
                  ensemble_forecast_shrt_029      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_029      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_030
                  ensemble_forecast_shrt_030      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_030      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_031
                  ensemble_forecast_shrt_031      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_031      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_032
                  ensemble_forecast_shrt_032      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_032      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_033
                  ensemble_forecast_shrt_033      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_033      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_034
                  ensemble_forecast_shrt_034      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_034      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_035
                  ensemble_forecast_shrt_035      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_035      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_036
                  ensemble_forecast_shrt_036      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_036      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_037
                  ensemble_forecast_shrt_037      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_037      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_038
                  ensemble_forecast_shrt_038      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_038      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_039
                  ensemble_forecast_shrt_039      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_039      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_040
                  ensemble_forecast_shrt_040      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_040      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_041
                  ensemble_forecast_shrt_041      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_041      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_042
                  ensemble_forecast_shrt_042      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_042      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_043
                  ensemble_forecast_shrt_043      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_043      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                  ensemble_ens_wiggle              => ensemble_forecast_shrt_044
                  ensemble_forecast_shrt_044      => ensemble_verificationmodel_database
                  ensemble_forecast_shrt_044      => ensembles_res_delete             \
                                                  & ensemble_sync_main
                ensemble_verificationmodel_database:start => ensemble_archive => housekeep
                ensemble_verificationmodel_database       => housekeep
                ensemble_forecast_end          => ensemble_sync_forecast    => housekeep
                ensemble_forecast_end          => ensemble_sync_main    => housekeep
                ensemble_verificationmodel_database        => ensemble_sync_verification     => housekeep
                ensemble_sync_forecast_tC     => housekeep
                ensemble_sync_happy          => housekeep
                long_assimilation_look_at_little => !recover1 & !recover2 & !recover3
                long_assimilation_look_at_little:fail => recover1
                recover1 => recover2
                recover2 => recover3
                recover3 | brief_assimilation_look_at_larger => brief_forecast
            """
[runtime]
    [[recover1, recover2, recover3]]
    [[ENSEMBLE]]
    [[ENCOLD_START]]
        inherit = ENSEMBLE
    [[ENSEMBLE_SHARED]]
        inherit = ENSEMBLE_HPC, CORETYPE_SHARED
    [[ENSEMBLE_PARALLEL]]
        inherit = ENSEMBLE_HPC, CORETYPE_PARALLEL
    [[ENSEMBLE_ENS]]
    [[ENSEMBLE_OBS]]
        inherit = ENSEMBLE, HPC, INSTALL_DIAG
    [[ENSEMBLE_ENS_ADDSURFACES]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_SHARED
    [[ENSEMBLE_ENS_WIGGLES]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_SHARED
    [[ENSEMBLE_FORECAST_REDO]]
    [[ENSEMBLE_FORECAST]]
    [[ENSEMBLE_FORECAST_CONTROL]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_PARALLEL, ENSEMBLE_FORECAST, ENSEMBLE_RES
    [[ENSEMBLE_FORECAST_LONG]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_PARALLEL, ENSEMBLE_FORECAST, ENSEMBLE_RES
    [[ENSEMBLE_FORECAST_SHRT]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_PARALLEL, ENSEMBLE_FORECAST, ENSEMBLES_RES
    [[ENSEMBLE_VERIFICATIONMODEL]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_SHARED
    [[ENSEMBLE_HPC]]
    [[ENSEMBLE_RES]]
    [[ENSEMBLES_RES]]
    [[ensemble_install_startdata_cold]]
        inherit = ENCOLD_START, HPC, CORETYPE_SHARED
    [[ensemble_start]]
        inherit = ENSEMBLE, LOCAL
    [[ensemble_ens_tidy_observations]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_ENS, ENSEMBLE_RES
    [[ensemble_ens_filter]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_ENS, ENSEMBLE_RES
    [[ensemble_observations_process_000]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_001]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_002]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_003]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_004]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_005]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_006]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_007]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_008]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_009]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_010]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_011]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_012]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_013]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_014]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_015]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_016]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_017]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_018]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_019]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_020]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_021]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_022]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_023]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_024]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_025]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_026]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_027]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_028]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_029]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_030]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_031]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_032]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_033]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_034]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_035]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_036]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_037]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_038]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_039]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_040]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_041]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_042]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_043]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_observations_process_044]]
        inherit = ENSEMBLE_OBS, ENSEMBLE_RES
    [[ensemble_ens_add_temps_001]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_002]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_003]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_004]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_005]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_006]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_007]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_008]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_009]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_010]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_011]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_012]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_013]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_014]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_015]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_016]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_017]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_018]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_019]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_020]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_021]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_022]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_023]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_024]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_025]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_026]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_027]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_028]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_029]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_030]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_031]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_032]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_033]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_034]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_035]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_036]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_037]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_038]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_039]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_040]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_041]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_042]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_043]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_add_temps_044]]
        inherit = ENSEMBLE_ENS_ADDSURFACES
    [[ensemble_ens_wiggle]]
        inherit = ENSEMBLE_ENS_WIGGLES
    [[ensemble_forecast_redo_long_look_at]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_SHARED, ENSEMBLE_FORECAST_REDO
    [[ensemble_forecast_long_000]]
        inherit = ENSEMBLE_FORECAST_CONTROL, ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_001]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_002]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_003]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_004]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_005]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_006]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_007]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_008]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_009]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_010]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_011]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_012]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_013]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_014]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_015]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_016]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_017]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_018]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_019]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_020]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_021]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_long_022]]
        inherit = ENSEMBLE_FORECAST_LONG
    [[ensemble_forecast_shrt_001]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_002]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_003]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_004]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_005]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_006]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_007]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_008]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_009]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_010]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_011]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_012]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_013]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_014]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_015]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_016]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_017]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_018]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_019]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_020]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_021]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_022]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_023]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_024]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_025]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_026]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_027]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_028]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_029]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_030]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_031]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_032]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_033]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_034]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_035]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_036]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_037]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_038]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_039]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_040]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_041]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_042]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_043]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_forecast_shrt_044]]
        inherit = ENSEMBLE_FORECAST_SHRT
    [[ensemble_verificationmodel_database]]
        inherit = ENSEMBLE_VERIFICATIONMODEL
    [[ensemble_archive]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, ARCHIVE
[runtime]
    [[ENSEMBLE_FORECAST_TRIGGER]]
        inherit = ENSEMBLE, HPC, CORETYPE_SHARED
    [[ENSEMBLE_SUBJOB]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, CORETYPE_SHARED
    [[ENSEMBLE_THUNDERBIRDS_ARE_GO]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC
    [[ENSEMBLE_MIRROR]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, CORETYPE_SHARED
    [[ensemble_start_00, ensemble_start_06, ensemble_start_12, ensemble_start_18]]
        inherit = ENSEMBLE, OS_START
    [[ensemble_forecast_end]]
        inherit = ENSEMBLE, LOCAL
    [[ensemble_user_hook]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, CORETYPE_SHARED
    [[ensemble_res_create, ensembles_res_create]]
        inherit = OS_RES_CREATE, ENSEMBLE_HPC
    [[ensemble_res_delete, ensembles_res_delete]]
        inherit = OS_RES_DELETE, ENSEMBLE_HPC
    [[ensemble_sync_main, ensemble_sync_forecast, ensemble_sync_happy]]
        inherit = ENSEMBLE_MIRROR
    [[ensemble_sync_forecast_tC]]
        inherit = ENSEMBLE_MIRROR
    [[ensemble_sync_verification]]
        inherit = ENSEMBLE_MIRROR
    [[ensemble_forecast_000_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_000_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_001_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_002_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_003_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_004_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_005_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_006_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_007_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_008_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_009_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_010_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_011_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_012_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_013_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_014_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_015_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_016_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_017_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_018_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_019_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_020_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_021_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tC]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tI]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tJ]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tK]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tL]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tM]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tN]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tO]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_022_tP]]
        inherit = ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_HPC
    [[ensemble_forecast_all_tK]]
        inherit = ENSEMBLE, LOCAL
    [[ensemble_forecast_subjob_000_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_000_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_updown_or_000]]
	    inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_thunderbirds_are_go_forecast_000]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_001_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_001_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_001]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_002_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_002_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_002]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_003_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_003_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_003]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_004_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_004_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_004]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_005_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_005_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_005]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_006_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_006_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_006]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_007_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_007_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_007]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_008_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_008_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_008]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_009_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_009_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_009]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_010_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_010_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_010]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_011_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_011_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_011]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_012_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_012_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_012]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_013_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_013_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_013]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_014_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_014_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_014]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_015_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_015_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_015]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_016_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_016_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_016]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_017_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_017_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_017]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_018_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_018_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_018]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_019_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_019_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_019]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_020_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_020_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_020]]
            inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_021_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_021_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_021]]
        inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_forecast_subjob_022_tC]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tI]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tJ]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tK]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tL]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tM]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tN]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tO]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_tP]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_sdfk]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_forecast_subjob_022_sduv]]
        inherit = ENSEMBLE_SUBJOB
    [[ensemble_thunderbirds_are_go_forecast_022]]
        inherit = ENSEMBLE_THUNDERBIRDS_ARE_GO
    [[ensemble_local]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, CORETYPE_SHARED
    [[ensemble_downscale]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, CORETYPE_SHARED
    [[ensemble_subjob_hook]]
        inherit = ENSEMBLE, HPC, ENSEMBLE_HPC, CORETYPE_SHARED
[scheduling]
    [[dependencies]]
        [[[ T00, T06, T12, T18 ]]]
            graph = """
                long_forecast_end => long_zoom_frozen_happyland => long_zoom_send_to_highway_happyland_yay
                long_zoom_send_to_highway_happyland_yay => long_zoom_send_notification_to_highway_happyland_yay
                long_zoom_send_notification_to_highway_happyland_yay => housekeep
                long_forecast_end => long_zoom_frozen_happyland => long_zoom_send_to_highway_happyland_yay2
                long_zoom_send_to_highway_happyland_yay2 => long_zoom_send_notification_to_highway_happyland_yay2
                long_zoom_send_notification_to_highway_happyland_yay2 => housekeep
            """
[runtime]
    [[LONG_ZOOM_SUBJOB]]
        inherit = LONG, HPC, LONG_HPC
    [[LONG_ZOOM_SEND_TO_HIGHWAY]]
        inherit = LONG_ZOOM_SUBJOB
     [[HAPPYLAND_ENV]]
     [[LONG_ZOOM_SEND_HAPPYLAND]]
       inherit = LONG_ZOOM_SEND_TO_HIGHWAY
        [[LONG_ZOOM_SEND_HAPPYLAND_yay]]
            inherit = LONG_ZOOM_SEND_HAPPYLAND
        [[LONG_ZOOM_SEND_HAPPYLAND_yay2]]
            inherit = LONG_ZOOM_SEND_HAPPYLAND
    [[long_zoom_frozen_happyland]]
        inherit = LONG_ZOOM_SUBJOB, HAPPYLAND_ENV
        [[long_zoom_send_to_highway_happyland_yay]]
            inherit = LONG_ZOOM_SEND_HAPPYLAND_yay, HAPPYLAND_ENV
        [[long_zoom_send_notification_to_highway_happyland_yay]]
            inherit = LONG_ZOOM_SEND_HAPPYLAND_yay, HAPPYLAND_ENV
        [[long_zoom_send_to_highway_happyland_yay2]]
            inherit = LONG_ZOOM_SEND_HAPPYLAND_yay2, HAPPYLAND_ENV
        [[long_zoom_send_notification_to_highway_happyland_yay2]]
            inherit = LONG_ZOOM_SEND_HAPPYLAND_yay2, HAPPYLAND_ENV
[visualization]
    default node attributes = style=filled, color=black, shape=box, fillcolor=khaki
    collapsed families = \
        LONG_FORECAST_TRIGGER, BRIEF_FORECAST_TRIGGER, LONG_SUBJOB, BRIEF_SUBJOB, LONG_DISPERSION,  \
        LONG_DISPERSION_PROC, LONG_DISPERSION_ARCHIVING, LONG_DISPERSION_HOUSEKEEPING,  \
        COLD_START, BRIEF_OBSERVATIONS_PROCESS_BACKGROUND, LONG_OBS_PROCESS_BACKGROUND,   \
        BRIEF_OBS_PROCESS_LOOK_AT, LONG_OBS_PROCESS_LOOK_AT, LONG_OBS_DB_STUFF, BRIEF_OBS_DB_STUFF,   \
        BRIEF_SURFACE_LANDSIM, \
        ENSEMBLE_FORECAST_TRIGGER, ENSEMBLE_SUBJOB, \
        ENSEMBLE_FORECAST_CONTROL, ENSEMBLE_FORECAST_LONG, ENSEMBLE_FORECAST_SHRT, \
        ENSEMBLE_OBS, ENSEMBLE_ENS_ADDSURFACES, ENSEMBLE_ENS_WIGGLES, ENSEMBLE_VERIFICATIONMODEL, ENCOLD_START
    [[node groups]]
        archive_nodes = long_archive_short, long_archive_long, brief_archive
    [[node attributes]]
        long_start = fillcolor=violet
        brief_start = fillcolor=violet
        LONG_OBS = fillcolor=palegreen
        BRIEF_OBS = fillcolor=palegreen
        LONG_FORECAST_TRIGGER = fillcolor=powderblue
        BRIEF_FORECAST_TRIGGER = fillcolor=powderblue
        LONG_DISPERSION = fillcolor=powderblue
        LONG_DISPERSION_PROC = fillcolor=powderblue
        LONG_DISPERSION_ARCHIVING = fillcolor=powderblue
        LONG_DISPERSION_HOUSEKEEPING = fillcolor=powderblue
        LONG_SUBJOB = fillcolor=powderblue
        BRIEF_SUBJOB = fillcolor=powderblue
        BRIEF_SURFACE = fillcolor=burlywood
        COLD_START = style=rounded
        LONGBRIEF_FORECAST_REDO = fillcolor=gold
        archive_nodes = fillcolor=tomato
        ENCOLD_START = style=rounded
        ensemble_start = fillcolor=violet
        ENSEMBLE_OBS = fillcolor=orange
        ENSEMBLE_ENS_ADDSURFACES = fillcolor=cyan
        ENSEMBLE_ENS_WIGGLES = fillcolor=springgreen
        ENSEMBLE_FORECAST = fillcolor=dodgerblue, fontsize=20
        ENSEMBLE_VERIFICATIONMODEL = fillcolor=palegreen
        ENSEMBLE_FORECAST_TRIGGER = fillcolor=powderblue
        ENSEMBLE_SUBJOB = fillcolor=powderblue
        ensemble_archive = fillcolor=tomato
        OS_START = fillcolor=peru
        OS_RES_CREATE = fillcolor=peru
        OS_RES_DELETE = fillcolor=peru
        housekeep = fillcolor=tomato
        install_cold = style=rounded
        install_cold_mirror = style=rounded
